@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2020, Ilya Kotov <forkotov02@ya.ru>
+ * Copyright (c) 2014-2023, Ilya Kotov <forkotov02@ya.ru>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -42,9 +42,10 @@ public:
 QPlatformTheme *Qt5CTPlatformThemePlugin::create(const QString &key, const QStringList &params)
 {
     Q_UNUSED(params);
-    if (key.toLower() == "qt5ct")
+    if (key.toLower() == "qt5ct" || key.toLower() == "qt6ct")
         return new Qt5CTPlatformTheme();
-    return NULL;
+
+    return nullptr;
 }
 
 QT_END_NAMESPACE
