@@ -1,6 +1,7 @@
 #!/bin/sh
 
 PROJECT_NAME=qt5ct
+PROJECT_ORGANIZATION=qt-configuration-tool
 TX_CONFIG="../.tx/config"
 
 echo "[main]" > ${TX_CONFIG}
@@ -16,7 +17,7 @@ do
 
 
      file_filter=`echo ${tr_dir} | sed 's/..\///'`
-     echo "[${PROJECT_NAME}.${plug_name}]" >> ${TX_CONFIG}
+     echo "[o:${PROJECT_ORGANIZATION}:p:${PROJECT_NAME}:r:${plug_name}]" >> ${TX_CONFIG}
      echo "file_filter = ${file_filter}/${plug_name}_<lang>.ts" >> ${TX_CONFIG}
      echo "source_lang = en" >> ${TX_CONFIG}
      echo "source_file = ${file_filter}/${plug_name}_en.ts" >> ${TX_CONFIG}
@@ -28,7 +29,7 @@ done
 
 for RESOURCE_NAME in qt5ct
 do
-    echo "[${PROJECT_NAME}.${RESOURCE_NAME}-desktop]" >> ${TX_CONFIG}
+    echo "[o:${PROJECT_ORGANIZATION}:p:${PROJECT_NAME}:r:${RESOURCE_NAME}-desktop]" >> ${TX_CONFIG}
     echo "file_filter = src/qt5ct/desktop-translations/${RESOURCE_NAME}_<lang>.desktop.in" >> ${TX_CONFIG}
     echo "source_lang = en" >> ${TX_CONFIG}
     echo "source_file = src/qt5ct/${RESOURCE_NAME}.desktop" >> ${TX_CONFIG}
